@@ -31,6 +31,13 @@ all_images = pytest.mark.testinfra_hosts(*[
     )
 ])
 
+centos_images = pytest.mark.testinfra_hosts(*[
+    "docker://{}".format(image)
+    for image in (
+        "centos_6", "centos_7",
+    )
+])
+
 
 @all_images
 def test_package(host, docker_image):
@@ -72,6 +79,14 @@ def test_held_package(host):
     assert python.version.startswith("2.7.")
 
 
+@pytest.mark.destructive
+@centos_images
+def test_non_default_package_tool(host):
+    # Make non default pkg tool binary present
+    host.run("install -m a+rx /bin/true /usr/bin/dpkg-query")
+    assert host.package("openssh").is_installed
+
+
 @pytest.mark.destructive
 def test_uninstalled_package_version(host):
     with pytest.raises(AssertionError) as excinfo:
@@ -163,7 +178,10 @@ def test_puppet_resource(host):
 
 def test_facter(host):
     assert host.facter()["os"]["distro"]["codename"] == "buster"
-    assert host.facter("virtual") == {"virtual": "docker"}
+    assert host.facter("virtual") in (
+        {"virtual": "docker"},
+        {'virtual': 'hyperv'},  # github action uses hyperv
+    )
 
 
 def test_sysctl(host):
@@ -572,13 +590,11 @@ def test_addr(host):
     google_dns = host.addr('8.8.8.8')
     assert google_dns.is_resolvable
     assert google_dns.ipv4_addresses == ['8.8.8.8']
-    assert google_dns.is_reachable
     assert google_dns.port(53).is_reachable
     assert not google_dns.port(666).is_reachable
 
     google_addr = host.addr('google.com')
     assert google_addr.is_resolvable
-    assert google_addr.is_reachable
     assert google_addr.port(443).is_reachable
     assert not google_addr.port(666).is_reachable
 
